@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package MetaCPAN::Client::ResultSet;
 # ABSTRACT: A Result Set
-$MetaCPAN::Client::ResultSet::VERSION = '2.024000';
+$MetaCPAN::Client::ResultSet::VERSION = '2.027000';
 use Moo;
 use Carp;
 
@@ -108,12 +108,12 @@ MetaCPAN::Client::ResultSet - A Result Set
 
 =head1 VERSION
 
-version 2.024000
+version 2.027000
 
 =head1 DESCRIPTION
 
 Object representing a result from Elastic Search. This is used for the complex
-(as in L<non-simple/MetaCPAN::Client/"SEARCH SPEC">) queries to MetaCPAN. It
+(as in L<non-simple|MetaCPAN::Client/"SEARCH SPEC">) queries to MetaCPAN. It
 provides easy access to the scroller and aggregations.
 
 =head1 ATTRIBUTES
